<?php

/**
 * Сниппет Thumb2x
 * @var modX $modx
 * @var array $scriptProperties
 */

$corePath = $modx->getOption('thumb2x.core_path', null, MODX_CORE_PATH . 'components/thumb2x/');
$modelPath = $corePath . 'model/';

require_once $corePath . 'vendor/autoload.php';
if (!class_exists('Thumb2xHandler')) {
    require_once $corePath . 'model/thumb2xhandler.class.php'; }

$modx->addPackage('thumb2x', $modelPath);

try {
    $handler = new Thumb2xHandler($modx);
} catch (Exception $e) {
    $modx->log(modX::LOG_LEVEL_ERROR, '[Thumb2x] Не удалось создать экземпляр обработчика: ' . $e->getMessage());
    return 'Ошибка инициализации обработчика.';
}

$input = $modx->getOption('input', $scriptProperties, '');
if (empty($input)) {
    return 'Не указан исходный файл.';
}

$options = $modx->getOption('options', $scriptProperties, []);

if (is_string($options) && !empty($options)) {
    parse_str(trim($options, '`'), $options);
}


$defaultSourceId = (int)$modx->getOption('thumb2x.source_id', null, 1);
$sourceId = (int)$modx->getOption('sourceId', $scriptProperties, $defaultSourceId);

$overrides = [];
if ($quality = $modx->getOption('quality', $scriptProperties, null)) {
    $overrides['thumbnail_quality'] = (int)$quality;
}
if ($format = $modx->getOption('format', $scriptProperties, null)) {
    $overrides['thumbnail_type'] = $format;
}
if ($watermark = $modx->getOption('watermark', $scriptProperties, null)) {
    $overrides['watermark_path'] = $watermark;
}

return $handler->getUrl($input, $options, $sourceId, $overrides);