<?php
/**
 * Удаляет одну или несколько записей (и их файлы) из кэша Thumb2x.
 *
 */
class Thumb2xItemRemoveProcessor extends modProcessor
{
    /**
     * @var string Имя класса объекта. Убедитесь, что оно совпадает с вашей xPDO-схемой.
     */
    public $classKey = 'Thumb2xFile';
    /**
     * @var string Ключ для лексиконов (например, 'thumb2x_item_err_nf')
     */
    public $objectType = 'thumb2x_item';
    /**
     * @var array Массив тем лексиконов для загрузки
     */
    public $languageTopics = ['thumb2x:default'];

    /**
     * @return array|string
     */
    public function process()
    {


        $ids = json_decode($this->getProperty('ids'), true);
        if (empty($ids)) {
            return $this->failure($this->modx->lexicon($this->objectType . '_err_ns'));
        }

        foreach ($ids as $id) {
            /** @var modResource $object */
            if (!$object = $this->modx->getObject($this->classKey, $id)) {

                return $this->failure($this->modx->lexicon($this->objectType . '_err_nf'));
            }

                        $path = $object->get('cache_path');
            if (!empty($path)) {
                                $fullPath = MODX_BASE_PATH . ltrim($path, '/');

                if (file_exists($fullPath) && is_file($fullPath)) {
                    if (@unlink($fullPath)) {
                                                $dir = dirname($fullPath);
                                                if (is_dir($dir) && count(scandir($dir)) == 2) {
                            @rmdir($dir);
                        }
                    }
                }
            }

                        if ($object->remove() === false) {
                return $this->failure($this->modx->lexicon($this->objectType . '_err_remove'));
            }
        }

        return $this->success();
    }
}

return 'Thumb2xItemRemoveProcessor';