<?php

/**
 * Очищает кэш компонента Thumb2x: удаляет все файлы из папки кэша и все записи из таблицы.
 *
 */
class Thumb2xItemTruncateProcessor extends modProcessor
{
    /**
     * @return array|string
     */
    public function process()
    {
        // 1. Очищаем папку с файлами кэша
        $cachePath = MODX_ASSETS_PATH . 'components/thumb2x/cache/';
        if (is_dir($cachePath)) {

            $this->deleteDir($cachePath, false);
        }

        // 2. Очищаем таблицу в базе данных

        $tableName = $this->modx->getTableName('Thumb2xFile');
        if ($tableName) {
            $this->modx->exec("TRUNCATE TABLE {$tableName}");
        }


        return $this->success($this->modx->lexicon('thumb2x_truncate_success'));
    }

    /**
     * Рекурсивно удаляет содержимое директории.
     * @param string $dirPath
     * @param bool $deleteMe
     */
    private function deleteDir($dirPath, $deleteMe = true)
    {
        if (!is_dir($dirPath)) {
            return;
        }

        $iterator = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($dirPath, FilesystemIterator::SKIP_DOTS),
            RecursiveIteratorIterator::CHILD_FIRST
        );
        foreach ($iterator as $path) {
            $path->isDir() && !$path->isLink() ? rmdir($path->getPathname()) : unlink($path->getPathname());
        }
        if ($deleteMe) {
            rmdir($dirPath);
        }
    }
}

return 'Thumb2xItemTruncateProcessor';