thumb2x.grid.Items = function (config) {
    config = config || {};
    if (!config.id) {
        config.id = 'thumb2x-grid-items';
    }
    Ext.applyIf(config, {
        url: thumb2x.config.connector_url,
        fields: this.getFields(config),
        columns: this.getColumns(config),
        tbar: this.getTopBar(config),
        sm: new Ext.grid.CheckboxSelectionModel(),
        baseParams: {
            
            action: 'mgr/item/getlist'
        },
        viewConfig: {
            forceFit: true,
            enableRowBody: true,
            autoFill: true,
            showPreview: true,
            scrollOffset: 0
        },
        paging: true,
        remoteSort: true,
        autoHeight: true,
    });
    thumb2x.grid.Items.superclass.constructor.call(this, config);
};
Ext.extend(thumb2x.grid.Items, MODx.grid.Grid, {
    windows: {},

    getMenu: function (grid, rowIndex) {
        
        var row = grid.getStore().getAt(rowIndex);
        var menu = thumb2x.utils.getMenu(row.data.actions, this, row.data.id);
        this.addContextMenuItem(menu);
    },

    removeItem: function () {
        
        var ids = this._getSelectedIds();
        if (!ids.length) {
            return false;
        }
        MODx.msg.confirm({
            title: ids.length > 1 ? _('thumb2x_files_remove') : _('thumb2x_file_remove'),
            text: ids.length > 1 ? _('thumb2x_files_remove_confirm') : _('thumb2x_file_remove_confirm'),
            url: this.config.url,
            params: {
                // ИЗМЕНЕНО: Формат вызова процессора для MODX 2
                action: 'mgr/item/remove',
                ids: Ext.util.JSON.encode(ids),
            },
            listeners: {
                success: {
                    fn: function () { this.refresh(); },
                    scope: this
                }
            }
        });
        return true;
    },

    truncate: function (btn, e) {
        MODx.msg.confirm({
            title: _('thumb2x_truncate_all'),
            text: _('thumb2x_truncate_confirm'),
            url: this.config.url,
            params: {
                // ИЗМЕНЕНО: Формат вызова процессора для MODX 2
                action: 'mgr/item/truncate'
            },
            listeners: {
                success: {
                    fn: function () {
                        this.refresh();
                    }, scope: this
                }
            }
        });
    },

    getFields: function () {
        return [
            'id', 'source_path', 'cache_path', 'params', 'cache_filesize',
            'cache_width', 'cache_height', 'createdon', 'accessedon', 'actions'
        ];
    },

    getColumns: function () {
        return [{
            header: _('id'),
            dataIndex: 'id',
            sortable: true,
            hidden: true
        }, {
            header: _('thumb2x_preview'),
            dataIndex: 'cache_path',
            sortable: false,
            width: 100,
            renderer: function(value) {
                if (value) {
                    
                    var fullUrl = MODx.config.base_url + value;
                    return '<a href="' + fullUrl + '" target="_blank"><img src="' + fullUrl + '" alt="" style="height: 50px; max-width: 90px; object-fit: contain;"></a>';
                }
                return '';
            }
        }, {
            header: _('thumb2x_source_path'),
            dataIndex: 'source_path',
            sortable: true,
            width: 250
        }, {
            header: _('thumb2x_dimensions'),
            dataIndex: 'cache_width',
            sortable: true,
            width: 100,
            renderer: function(value, meta, record) {
                return record.data.cache_width + 'x' + record.data.cache_height;
            }
        }, {
            header: _('thumb2x_filesize'),
            dataIndex: 'cache_filesize',
            sortable: true,
            width: 100,
            renderer: function(value) {
                
                var size = parseInt(value, 10);
                if (size === 0 || typeof thumb2x.utils.formatFileSize !== 'function') {
                    return '0 B';
                }
                return thumb2x.utils.formatFileSize(size);
            }
        }, {
            header: _('thumb2x_createdon'),
            dataIndex: 'createdon',
            sortable: true,
            width: 150,
            renderer: Ext.util.Format.dateRenderer(MODx.config.manager_date_format + ' ' + MODx.config.manager_time_format)
        }, {
            header: _('thumb2x_accessedon'),
            dataIndex: 'accessedon',
            sortable: true,
            width: 150,
            renderer: Ext.util.Format.dateRenderer(MODx.config.manager_date_format + ' ' + MODx.config.manager_time_format)
        }, {
            header: _('thumb2x_grid_actions'),
            dataIndex: 'actions',
            renderer: thumb2x.utils.renderActions,
            sortable: false,
            width: 100,
            id: 'actions'
        }];
    },

    getTopBar: function () {
        return [{
            text: '<i class="icon icon-trash"></i> ' + _('thumb2x_truncate_all'),
            handler: this.truncate,
            scope: this
        }, '->', {
            xtype: 'textfield',
            name: 'query',
            emptyText: _('thumb2x_search'),
            listeners: {
                change: { fn: this._doSearch, scope: this },
                render: { fn: function(cmp) {
                        new Ext.KeyMap(cmp.getEl(), {
                            key: Ext.EventObject.ENTER,
                            fn: function() {
                                this.fireEvent('change', this);
                                this.blur();
                                return true;
                            },
                            scope: cmp
                        });
                    }, scope: this }
            }
        }, {
            xtype: 'button',
            text: _('thumb2x_clear'),
            listeners: {
                click: {
                    fn: function(btn) {
                        
                        var searchField = btn.ownerCt.find('name', 'query')[0];
                        this._clearSearch(searchField);
                    },
                    scope: this
                }
            }
        }];
    },

    onClick: function (e) {
        
        var elem = e.getTarget();
        if (elem.nodeName === 'BUTTON') {
            var row = this.getSelectionModel().getSelected();
            if (typeof (row) != 'undefined') {
                var action = elem.getAttribute('action');
                if (action === 'showMenu') {
                    var ri = this.getStore().find('id', row.id);
                    return this._showMenu(this, ri, e);
                } else if (typeof this[action] === 'function') {
                    this.menu.record = row.data;
                    return this[action](this, e);
                }
            }
        }
        return this.processEvent('click', e);
    },

    _getSelectedIds: function () {
        
        var ids = [];
        var selected = this.getSelectionModel().getSelections();
        for (var i in selected) {
            if (!selected.hasOwnProperty(i)) {
                continue;
            }
            ids.push(selected[i]['id']);
        }
        return ids;
    },

    _doSearch: function (tf) {
        this.getStore().baseParams.query = tf.getValue();
        this.getBottomToolbar().changePage(1);
    },

    _clearSearch: function (tf) {
        if (tf) {
            tf.setValue('');
        }
        this.getStore().baseParams.query = '';
        this.getBottomToolbar().changePage(1);
    },
});
Ext.reg('thumb2x-grid-items', thumb2x.grid.Items);